@@ -1,6 +1,6 @@
 # encoding: utf-8
 #  Phusion Passenger - https://www.phusionpassenger.com/
-#  Copyright (c) 2010-2015 Phusion Holding B.V.
+#  Copyright (c) 2010-2016 Phusion Holding B.V.
 #
 #  "Passenger", "Phusion Passenger" and "Union Station" are registered
 #  trademarks of Phusion Holding B.V.
@@ -31,10 +31,10 @@ module PhusionPassenger
 
   PACKAGE_NAME = 'passenger'
   # Run 'rake src/cxx_supportlib/Constants.h' after changing this number.
-  VERSION_STRING = '5.0.23'
+  VERSION_STRING = '5.0.28'
 
-  PREFERRED_NGINX_VERSION = '1.8.0'
-  NGINX_SHA256_CHECKSUM = '23cca1239990c818d8f6da118320c4979aadf5386deda691b1b7c2c96b9df3d5'
+  PREFERRED_NGINX_VERSION = '1.10.0'
+  NGINX_SHA256_CHECKSUM = '8ed647c3dd65bc4ced03b0e0f6bf9e633eff6b01bac772bcf97077d58bc2be4d'
 
   PREFERRED_PCRE_VERSION  = '8.34'
   PCRE_SHA256_CHECKSUM = '1dd78994c81e44ac41cf30b2a21d4b4cc6d76ccde7fc6e77713ed51d7bddca47'
@@ -235,6 +235,20 @@ module PhusionPassenger
     require("#{ruby_libdir}/phusion_passenger/#{name}")
   end
 
+  # Forward define public_api.rb methods for code that tries to hook
+  # Passenger events before an app is spawned (such as mongoid)
+  def self.on_event(name, &block)
+    # The definition in `public_api.rb` will override this implementation when
+    # a Ruby application is spawned.
+    nil
+  end
+
+  def self.call_event(name, *args)
+    # The definition in `public_api.rb` will override this implementation when
+    # a Ruby application is spawned.
+    nil
+  end
+
 
 private
   def self.infer_install_spec
